@@ -14,6 +14,7 @@ from .dicomweb_servers import DicomWebServers
 from .modalities import DicomModalities
 from .change import Change, ChangeType, ResourceType
 from .transfers import Transfers
+from .peers import Peers
 
 
 logger = logging.getLogger('api-client')
@@ -53,6 +54,7 @@ class OrthancApiClient(HttpClient):
         self.modalities = DicomModalities(api_client=self)
         self.jobs = Jobs(api_client=self)
         self.transfers = Transfers(api_client=self)
+        self.peers = Peers(api_client=self)
 
     def wait_started(self, timeout: float = None) -> bool:
         return wait_until(self.is_alive, timeout)
